evince r3413 - in trunk: . libdocument properties



Author: chpe
Date: Wed Feb  4 14:32:46 2009
New Revision: 3413
URL: http://svn.gnome.org/viewvc/evince?rev=3413&view=rev

Log:
	* libdocument/ev-init.c: (ev_init): Make ev_init() also bind the
	evince gettext domain, so i18n works in the library.

	* properties/ev-properties-main.c: (nautilus_module_initialize):
	Remove extra bindtextdomain call.

Modified:
   trunk/ChangeLog
   trunk/libdocument/ev-init.c
   trunk/properties/ev-properties-main.c

Modified: trunk/libdocument/ev-init.c
==============================================================================
--- trunk/properties/ev-properties-main.c	(original)
+++ trunk/properties/ev-properties-main.c	Wed Feb  4 14:32:46 2009
@@ -133,10 +133,6 @@
 	ev_properties_plugin_register_type (module);
 	ev_properties_view_register_type (module);
 
-	/* set up translation catalog */
-	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-
         ev_init ();
 }
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/libdocument/ev-init.c	(original)
+++ trunk/libdocument/ev-init.c	Wed Feb  4 14:32:46 2009
@@ -20,6 +20,7 @@
 #include <config.h>
 
 #include <glib.h>
+#include <glib/gi18n-lib.h>
 
 #include "ev-init.h"
 #include "ev-backends-manager.h"
@@ -31,7 +32,8 @@
 /**
  * ev_init:
  *
  * Initializes the evince document library.
  *
  * You must call this before calling any other function in the evince
  * document library.
@@ -46,6 +48,10 @@
         if (ev_init_count++ > 0)
                 return have_backends;
 
+	/* set up translation catalog */
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
         _ev_debug_init ();
         _ev_file_helpers_init ();
         have_backends = _ev_backends_manager_init ();
@@ -31,7 +32,8 @@
  * ev_init:
  *
- * Initializes the evince document library.
+ * Initializes the evince document library, and binds the evince
+ * gettext domain.
  *
  * You must call this before calling any other function in the evince

Modified: trunk/properties/ev-properties-main.c
==============================================================================